@@ -601,10 +601,12 @@ list_properties (IndicateIndicator * indicator)
 	GList * keys = g_hash_table_get_keys(priv->properties);
 	GPtrArray * properties = g_ptr_array_sized_new(g_list_length(keys) + 1);
 
-	for (; keys != NULL; keys = keys->next) {
-		g_ptr_array_add(properties, g_strdup(keys->data));
+	GList * l;
+	for (l=keys; l!=NULL; l=l->next) {
+		g_ptr_array_add(properties, g_strdup(l->data));
 	}
 
+	g_list_free (keys);
 	return properties;
 }
 
