@@ -78,12 +78,15 @@ proxy_t_equal (gconstpointer pa, gconstpointer pb)
 {
 	proxy_t * a = (proxy_t *)pa; proxy_t * b = (proxy_t *)pb;
 
-	if (a->connection == b->connection) {
-		return g_strcmp0(a->name, b->name);
-	} else {
-		/* we're only using this for equal, not sorting */
-		return 1;
-	}
+	if  (a->connection == b->connection) {
+	        if (g_strcmp0(a->name, b->name) == 0) {
+		        return g_strcmp0(a->path, b->path);
+		}
+        }
+
+       /* we're only using this for equal, not sorting */
+       return 1;
+
 }
 
 typedef struct {
@@ -261,7 +264,7 @@ static void
 indicate_listener_dispose (GObject * obj)
 {
 	IndicateListener * listener = INDICATE_LISTENER(obj);
-	IndicateListenerPrivate * priv = INDICATE_LISTENER_GET_PRIVATE(listener);
+        IndicateListenerPrivate * priv = INDICATE_LISTENER_GET_PRIVATE(listener);
 
 	if (priv->signal_subscription != 0) {
 		g_dbus_connection_signal_unsubscribe(priv->session_bus, priv->signal_subscription);
@@ -575,6 +578,7 @@ todo_idle (gpointer data)
 		proxy_t searchitem;
 		searchitem.name = todo->name;
 		searchitem.connection = todo->bus;
+		searchitem.path = todo->path;
 
 		GList * proxyitem = g_list_find_custom(priv->proxies, &searchitem, proxy_t_equal);
 		if (proxyitem != NULL) {
@@ -954,49 +958,78 @@ get_property_cb (GObject * object, GAsyncResult * res, gpointer user_data)
 	if (error != NULL) {
 		g_warning("Unable to get property data: %s", error->message);
 		g_error_free(error);
-		return;
-	}
+	} else {
 
-	GVariant * value = g_variant_get_child_value(retvalue, 0);
-	if (g_variant_is_of_type(value, G_VARIANT_TYPE_VARIANT)) {
-		value = g_variant_get_variant(value);
-	}
-
-	switch (get_property_data->type) {
-	case PROPERTY_TYPE_VARIANT: {
-		/* Just pass the GVariant along. */
-		indicate_listener_get_property_variant_cb cb =(indicate_listener_get_property_variant_cb)get_property_data->cb;
-		cb(get_property_data->listener, get_property_data->server, get_property_data->indicator, get_property_data->property, value, get_property_data->data);
-		break;
-	}
-	case PROPERTY_TYPE_STRING: {
-		/* Just pass the string along. */
-		indicate_listener_get_property_cb cb = (indicate_listener_get_property_cb)get_property_data->cb;
-		cb(get_property_data->listener, get_property_data->server, get_property_data->indicator, get_property_data->property, g_variant_get_string(value, NULL), get_property_data->data);
-		break;
-	}
-	case PROPERTY_TYPE_TIME: {
-		/* Convert it to a time val */
-		indicate_listener_get_property_time_cb cb = (indicate_listener_get_property_time_cb)get_property_data->cb;
-		GTimeVal time;
-		if (g_time_val_from_iso8601(g_variant_get_string(value, NULL), &time)) {
-			cb(get_property_data->listener, get_property_data->server, get_property_data->indicator, get_property_data->property, &time, get_property_data->data);
+		GVariant * value = g_variant_get_child_value(retvalue, 0);
+		if (g_variant_is_of_type(value, G_VARIANT_TYPE_VARIANT)) {
+			GVariant * tmp = g_variant_get_variant(value);
+			g_variant_unref (value);
+			value = tmp;
 		}
-		break;
-	}
-	case PROPERTY_TYPE_INT: {
-		/* Take the string and convert it to an integer */
-		indicate_listener_get_property_int_cb cb = (indicate_listener_get_property_int_cb)get_property_data->cb;
-		cb(get_property_data->listener, get_property_data->server, get_property_data->indicator, get_property_data->property, g_variant_get_int32(value), get_property_data->data);
-		break;
-	}
-	case PROPERTY_TYPE_BOOL: {
-		/* Check to see if it's 'true', if not assume that
-		   it's false */
-		indicate_listener_get_property_bool_cb cb = (indicate_listener_get_property_bool_cb)get_property_data->cb;
-		cb(get_property_data->listener, get_property_data->server, get_property_data->indicator, get_property_data->property, g_variant_get_boolean(value), get_property_data->data);
-		break;
-	}
+
+		switch (get_property_data->type) {
+		case PROPERTY_TYPE_VARIANT: {
+			/* Just pass the GVariant along. */
+			indicate_listener_get_property_variant_cb cb =(indicate_listener_get_property_variant_cb)get_property_data->cb;
+			cb(get_property_data->listener,
+			   get_property_data->server,
+			   get_property_data->indicator,
+			   get_property_data->property,
+			   value,
+			   get_property_data->data);
+			break;
+		}
+		case PROPERTY_TYPE_STRING: {
+			/* Just pass the string along. */
+			indicate_listener_get_property_cb cb = (indicate_listener_get_property_cb)get_property_data->cb;
+			cb(get_property_data->listener,
+			   get_property_data->server,
+			   get_property_data->indicator,
+			   get_property_data->property,
+			   g_variant_get_string(value, NULL),
+			   get_property_data->data);
+			break;
+		}
+		case PROPERTY_TYPE_TIME: {
+			/* Convert it to a time val */
+			indicate_listener_get_property_time_cb cb = (indicate_listener_get_property_time_cb)get_property_data->cb;
+			GTimeVal time;
+			if (g_time_val_from_iso8601(g_variant_get_string(value, NULL), &time)) {
+				cb(get_property_data->listener,
+				   get_property_data->server,
+				   get_property_data->indicator,
+				   get_property_data->property,
+				   &time,
+				   get_property_data->data);
+			}
+			break;
+		}
+		case PROPERTY_TYPE_INT: {
+			/* Take the string and convert it to an integer */
+			indicate_listener_get_property_int_cb cb = (indicate_listener_get_property_int_cb)get_property_data->cb;
+			cb(get_property_data->listener,
+			   get_property_data->server,
+			   get_property_data->indicator,
+			   get_property_data->property,
+			   g_variant_get_int32(value),
+			   get_property_data->data);
+			break;
+		}
+		case PROPERTY_TYPE_BOOL: {
+			/* Check to see if it's 'true', if not assume that
+			   it's false */
+			indicate_listener_get_property_bool_cb cb = (indicate_listener_get_property_bool_cb)get_property_data->cb;
+			cb(get_property_data->listener,
+			   get_property_data->server,
+			   get_property_data->indicator,
+			   get_property_data->property,
+			   g_variant_get_boolean(value),
+			   get_property_data->data);
+			break;
+		}
+		}
+
+		g_variant_unref (value);
 	}
 
 	if (retvalue != NULL) {
@@ -1384,6 +1417,12 @@ indicate_listener_server_get_menu (IndicateListener * listener, IndicateListener
 	return get_server_property(listener, server, callback, NULL, "menu", data);
 }
 
+void
+indicate_listener_server_get_icon_theme (IndicateListener * listener, IndicateListenerServer * server, indicate_listener_get_server_property_cb callback, gpointer data)
+{
+	return get_server_property(listener, server, callback, NULL, "icontheme", data);
+}
+
 /**
  * indicate_listener_server_get_indicators:
  * @listener: The listener for the server
@@ -1406,6 +1445,7 @@ indicate_listener_server_get_indicators (IndicateListener * listener, IndicateLi
 	proxy_t searchitem;
 	searchitem.name = server->name;
 	searchitem.connection = server->connection;
+	searchitem.path = (gchar *)indicate_listener_server_get_dbuspath (server);
 
 	GList * proxyitem = g_list_find_custom(priv->proxies, &searchitem, proxy_t_equal);
 	if (proxyitem == NULL) {
@@ -1430,6 +1470,14 @@ indicate_listener_server_get_dbusname (IndicateListenerServer * server)
 	return server->name;
 }
 
+const gchar *
+indicate_listener_server_get_dbuspath (IndicateListenerServer *server)
+{
+        if (server == NULL) return NULL;
+  
+        return g_dbus_proxy_get_object_path (server->proxy);
+}
+
 guint
 indicate_listener_indicator_get_id (IndicateListenerIndicator * indicator)
 {
