@@ -79,7 +79,9 @@ enum {
 	PROP_DESKTOP,
 	PROP_TYPE,
 	PROP_COUNT,
-	PROP_MENU
+	PROP_MENU, 
+	PROP_PATH,
+	PROP_ICON_THEME
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -100,6 +102,8 @@ struct _IndicateServerPrivate
 
 	gchar * desktop;
 	gchar * type;
+	gchar * icon_theme;
+
 	guint count;
 
 	DbusmenuServer * dbusmenu;
@@ -408,6 +412,14 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                              "The DBus Object path to an object with a dbusmenu interface on it.",
 												  "",
 	                                              G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (gobj, PROP_PATH,
+					 g_param_spec_string("path", "DBus Path for server", "DBus path for the server object", "/com/canonical/indicate",
+							     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (gobj, PROP_ICON_THEME,
+					 g_param_spec_string("icon-theme", "Icon Theme Name",
+							     "The Custom Icon Theme Name to use when displaying this Server.",
+							     "",
+							     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	class->get_indicator_count = get_indicator_count;
 	class->get_indicator_list = get_indicator_list;
@@ -484,7 +496,7 @@ indicate_server_init (IndicateServer * server)
 
 	IndicateServerPrivate * priv = INDICATE_SERVER_GET_PRIVATE(server);
 
-	priv->path = g_strdup("/com/canonical/indicate");
+	priv->path = NULL;
 	priv->indicators = NULL;
 	priv->num_hidden = 0;
 	priv->visible = FALSE;
@@ -624,6 +636,18 @@ set_property (GObject * obj, guint id, const GValue * value, GParamSpec * pspec)
 		}
 		break;
 	}
+	case PROP_PATH:
+	        if (priv->path != NULL) {
+	                g_free(priv->path);
+	        }
+	        priv->path = g_value_dup_string(value);
+	        break;
+	case PROP_ICON_THEME:
+		if (priv->icon_theme != NULL) {
+			g_free (priv->icon_theme);
+		}
+		priv->icon_theme = g_value_dup_string(value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, id, pspec);
 		break;
@@ -671,6 +695,16 @@ get_property (GObject * obj, guint id, GValue * value, GParamSpec * pspec)
 			g_value_set_boxed(value, g_strdup("/"));
 		}
 		break;
+	case PROP_PATH:
+		g_value_set_string(value, priv->path);
+		break;
+	case PROP_ICON_THEME:
+		if (priv->icon_theme == NULL) {
+			g_value_set_string(value, "");
+		} else {
+			g_value_set_string(value, priv->icon_theme);
+		}
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, id, pspec);
 		break;
@@ -823,6 +857,12 @@ bus_get_prop (GDBusConnection * connection, const gchar * sender, const gchar *
 			retvariant = g_variant_new_string("/");
 		}
 
+	} else if (g_strcmp0(property, "icontheme") == 0) {
+		if (priv->icon_theme != NULL) {
+			retvariant = g_variant_new_string (priv->icon_theme);
+		} else {
+			retvariant = g_variant_new_string ("");
+		}
 	} else {
 		g_warning("Unknown property");
 	}
@@ -1447,6 +1487,26 @@ indicate_server_set_count (IndicateServer * server, guint count)
 	return;
 }
 
+/**
+ * indicate_server_set_icon_theme:
+ * @server: The #IndicateServer to set the type of
+ * @name: The name of an Icon Theme (according to the Icon Naming 
+ *        Specification) to request renderers of the server to use. 
+ * 
+ * This is a convience function to set the #IndicateServer:icon-theme
+ * property of the @server object.  The property can also be set
+ * via traditional means, but this one is easier to read.
+*/
+void
+indicate_server_set_icon_theme (IndicateServer * server, const gchar * name)
+{
+	GValue value = {0};
+	g_value_init(&value, G_TYPE_STRING);
+	g_value_set_string(&value, name);
+	g_object_set_property(G_OBJECT(server), "icon-theme", &value);
+	return;
+}
+
 static IndicateServer * default_indicate_interface_server = NULL;
 
 /**
@@ -1948,6 +2008,24 @@ indicate_server_get_next_id (IndicateServer * server)
 	return 0;
 }
 
+/**
+ * @indicate_server_get_path:
+ * @server: The #IndicateServer to get the path of.
+ *
+ * Gets DBus object path for the exported server object.
+ * 
+ * Return value: The servers DBus path.
+ */
+const gchar *
+indicate_server_get_path (IndicateServer *server)
+{
+	IndicateServerPrivate * priv = INDICATE_SERVER_GET_PRIVATE(server);
+
+        g_return_val_if_fail(INDICATE_IS_SERVER(server), NULL);
+
+        return priv->path;
+}
+
 static IndicateInterests
 interest_string_to_enum (const gchar * interest_string)
 {
